searchNodes=[{"doc":"HAP is an implementation of the HomeKit Accessory Protocol Specification. It allows for the creation of Elixir powered HomeKit accessories which can be controlled from a user's iOS device in a similar manner to commercially available HomeKit accessories such as light bulbs, window coverings and other smart home accessories.The HomeKit Data ModelThe data model of the HomeKit Accessory Protocol is represented as a tree structure. At the top level, a single HAP instance represents an Accessory Server. An accessory server hosts one or more Accessory Objects. Each accessory object represents a single, discrete physical accessory. In the case of directly connected devices, an accessory server typically hosts a single accessory object which represents device itself, whereas bridges will have one accessory object for each discrete physical object which they bridge to. Within HAP, an accessory server is represented by a HAP.AccessoryServer struct, and an accessory by the HAP.Accessory struct.Each accessory object contains exposes a set of Services, each of which represents a unit of functionality. As an example, a HomeKit accessory server which represented a ceiling fan with a light would contain one accessory object called 'Ceiling Fan', which would contain two services each representing the light and the fan. In addition to user-visible services, each accessory exposes an Accessory Information Service which contains information about the service's name, manufacturer, serial number and other properties. Within HAP, a service is represented by a HAP.Service struct.A service is made up of one or more Characteristics, each of which represents a specific aspect of the given service. For example, a light bulb service exposes an On Characteristic, which is a boolean value reflecting the current on or off state of the light. If it is a dimmable light, it may also expose a Brightness Characteristic. If it is a color changing light, it may also expose a Hue Characteristic. Within HAP, a characteristic is represented by a tuple of a HAP.CharacteristicDefinition and a value source.Using HAPHAP provides a high-level interface to the HomeKit Accessory Protocol, allowing an application to present any number of accessories to an iOS HomeKit controller. HAP is intended to be embedded within a host application which is responsible for providing the actual backing implementations of the various characteristics exposed via HomeKit. These are provided to HAP in the form of HAP.ValueStore implementations. For example, consider a Nerves application which exposes itself to HomeKit as a light bulb. Assume that the actual physical control of the light is controlled by GPIO pin 23. A typical configuration of HAP would look something like this:accessory_server = %HAP.AccessoryServer{ name: &quot;My HAP Demo Device&quot;, model: &quot;HAP Demo Device&quot;, identifier: &quot;11:22:33:44:12:66&quot;, accessory_type: 5, accessories: [ %HAP.Accessory{ name: &quot;My HAP Lightbulb&quot;, services: [ %HAP.Services.LightBulb{on: {MyApp.Lightbulb, gpio_pin: 23}} ] } ] ) children = [{HAP, accessory_server}] Supervisor.start_link(children, opts) ...In this example, the application developer is responsible for creating a MyApp.Lightbulb module which implements the HAP.ValueStore behaviour. This module would be called by HAP whenever it needs to change or query the current state of the light. The extra options (gpio_pin: 23 in the above example) are conveyed to this module on every call, allowing a single value store implementation to service any number of characteristics or services.HAP provides structs to represent the most common services, such as light bulbs, switches, and other common device types. HAP compiles these structs into generic HAP.Service structs when starting up, based on each source struct's implementation of the HAP.ServiceSource protocol. This allows for expressive definition of services by the application developer, while providing for less boilerplate within HAP itself. For users who wish to create additional device types not defined in HAP, users may define their accessories in terms of low-level HAP.Service and HAP.CharacteristicDefinition structs. For more information, consult the type definitions for HAP.AccessoryServer.t/0, HAP.Accessory.t/0, HAP.Service.t/0, HAP.Characteristic.t/0, and the HAP.CharacteristicDefinition behaviour.","ref":"HAP.html","title":"HAP","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"HAP.html#child_spec/1","title":"HAP.child_spec/1","type":"function"},{"doc":"Callback implementation for Supervisor.init/1.","ref":"HAP.html#init/1","title":"HAP.init/1","type":"function"},{"doc":"Starts a HAP instance based on the passed config","ref":"HAP.html#start_link/1","title":"HAP.start_link/1","type":"function"},{"doc":"Called by user applications whenever a characteristic value has changed. The change token is passed to HAP.ValueStore instances via the HAP.ValueStore.set_change_token/2 callback.","ref":"HAP.html#value_changed/1","title":"HAP.value_changed/1","type":"function"},{"doc":"Represents a single accessory object, containing a number of services","ref":"HAP.Accessory.html","title":"HAP.Accessory","type":"module"},{"doc":"The firmware recvision of this accessory, for example '1.0' or '1.0.1'","ref":"HAP.Accessory.html#t:firmware_revision/0","title":"HAP.Accessory.firmware_revision/0","type":"type"},{"doc":"The manufacturer of this accessory, for example 'HAP Co.'","ref":"HAP.Accessory.html#t:manufacturer/0","title":"HAP.Accessory.manufacturer/0","type":"type"},{"doc":"The model of this accessory, for example 'HAP Light Bulb Supreme'","ref":"HAP.Accessory.html#t:model/0","title":"HAP.Accessory.model/0","type":"type"},{"doc":"The name to advertise for this accessory, for example 'HAP Light Bulb'","ref":"HAP.Accessory.html#t:name/0","title":"HAP.Accessory.name/0","type":"type"},{"doc":"The serial number of this accessory, for example '0012345'","ref":"HAP.Accessory.html#t:serial_number/0","title":"HAP.Accessory.serial_number/0","type":"type"},{"doc":"Represents an accessory consisting of a number of services. Contains the following fields:name: The name to assign to this accessory, for example 'Ceiling Fan'model: The model name to assign to this accessory, for example 'FanCo Whisper III'manufacturer: The manufacturer of this accessory, for example 'FanCo'serial_number: The serial number of this accessory, for example '0012345'firmware_revision: The firmware revision of this accessory, for example '1.0'services: A list of services to include in this accessory","ref":"HAP.Accessory.html#t:t/0","title":"HAP.Accessory.t/0","type":"type"},{"doc":"Represents a top-level HAP instance configuration","ref":"HAP.AccessoryServer.html","title":"HAP.AccessoryServer","type":"module"},{"doc":"Generates the pairing url to be used to pair with this accessory server. This URL can be encoded in a QR code to enable pairing directly from an iOS device","ref":"HAP.AccessoryServer.html#pairing_url/1","title":"HAP.AccessoryServer.pairing_url/1","type":"function"},{"doc":"A unique identifier string in the form &quot;AA:BB:CC:DD:EE:FF&quot;","ref":"HAP.AccessoryServer.html#t:accessory_identifier/0","title":"HAP.AccessoryServer.accessory_identifier/0","type":"type"},{"doc":"A HAP specified value indicating the primary function of this device as found in Section 13 of Apple's HomeKit Accessory Protocol Specification. Valid values include:OtherBridgeFanGarageLightbulbDoor LockOutletSwitchThermostatSensorSecurity SystemDoorWindowWindow CoveringProgrammable SwitchRange ExtenderIP CameraVideo Door BellAir PurifierHeaterAir ConditionerHumidifierDehumidifierSprinklerFaucetShower SystemRemote","ref":"HAP.AccessoryServer.html#t:accessory_type/0","title":"HAP.AccessoryServer.accessory_type/0","type":"type"},{"doc":"The model of this accessory server, for example 'HAP Co. Super Bridge III'","ref":"HAP.AccessoryServer.html#t:model/0","title":"HAP.AccessoryServer.model/0","type":"type"},{"doc":"The name to advertise for this accessory server, for example 'HAP Bridge'","ref":"HAP.AccessoryServer.html#t:name/0","title":"HAP.AccessoryServer.name/0","type":"type"},{"doc":"A pairing code of the form 123-45-678","ref":"HAP.AccessoryServer.html#t:pairing_code/0","title":"HAP.AccessoryServer.pairing_code/0","type":"type"},{"doc":"A pairing URL suitable for display in a QR code","ref":"HAP.AccessoryServer.html#t:pairing_url/0","title":"HAP.AccessoryServer.pairing_url/0","type":"type"},{"doc":"A 4 character string used as part of the accessory discovery process","ref":"HAP.AccessoryServer.html#t:setup_id/0","title":"HAP.AccessoryServer.setup_id/0","type":"type"},{"doc":"Represents an accessory server consisting of a number of accessories. Contains the following fields:name: The name to assign to this device, for example 'HAP Bridge'model: The model name to assign to this device, for example 'HAP Co. Super Bridge III'identifier: A unique identifier string in the form &quot;AA:BB:CC:DD:EE:FF&quot;pairing_code: A pairing code of the form 123-45-678 to be used for pairing. If not specified one will be defined dynamically.setup_id: A 4 character string used as part of the accessory discovery process. If not specified one will be defined dynamically.display_module: An optional implementation of HAP.Display used to present pairing and other information to the user. If not specified then a basic console-based display is used.data_path: The path to where HAP will store its internal data. Will be created if it does not exist. If not specified, the default value depends on the value of Mix.target/0. If it is :host then a value of hap_data is used. If it is anything else (as it will be when compiling for a Nerves target, for example), the value of /root/hap_data is used. This allows HAP to work out-of-the-box in conventional and Nerves environments.accessory_type: A HAP specified value indicating the primary function of this device. See HAP.AccessoryServer.accessory_type/0 for detailsaccessories: A list of HAP.Accessory structs to include in this accessory server","ref":"HAP.AccessoryServer.html#t:t/0","title":"HAP.AccessoryServer.t/0","type":"type"},{"doc":"","ref":"HAP.EventManager.html","title":"HAP.EventManager","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"HAP.EventManager.html#child_spec/1","title":"HAP.EventManager.child_spec/1","type":"function"},{"doc":"","ref":"HAP.EventManager.html#get_listeners/2","title":"HAP.EventManager.get_listeners/2","type":"function"},{"doc":"Callback implementation for GenServer.init/1.","ref":"HAP.EventManager.html#init/1","title":"HAP.EventManager.init/1","type":"function"},{"doc":"","ref":"HAP.EventManager.html#register/3","title":"HAP.EventManager.register/3","type":"function"},{"doc":"","ref":"HAP.EventManager.html#start_link/1","title":"HAP.EventManager.start_link/1","type":"function"},{"doc":"","ref":"HAP.EventManager.html#unregister/3","title":"HAP.EventManager.unregister/3","type":"function"},{"doc":"A behaviour which encapsulates all user-facing display concerns for an accessory. Applications which use HAP may provide their own implementation of this behaviour as a field in a HAP.AccessoryServer. If no such implementation is provided HAP uses a default console based implementation","ref":"HAP.Display.html","title":"HAP.Display","type":"behaviour"},{"doc":"Stop displaying any currently displayed pairing information to the user. This is most commonly because a pairing has been established with a controller","ref":"HAP.Display.html#c:clear_pairing_code/0","title":"HAP.Display.clear_pairing_code/0","type":"callback"},{"doc":"Display a notification to the user containing information on how to pair with this accessory server. The value of pairing_url can be encoded in a QR code to enable pairing directly from an iOS device.","ref":"HAP.Display.html#c:display_pairing_code/3","title":"HAP.Display.display_pairing_code/3","type":"callback"},{"doc":"Display a notification to the user that identifies the named device or accessory. This comes from a user request within the Home app to identify the given device or accessory.","ref":"HAP.Display.html#c:identify/1","title":"HAP.Display.identify/1","type":"callback"},{"doc":"Defines the behaviour required of a module that wishes to act as the backing data store for a given HomeKit characteristicSimple Value StoreTo implement a value store for a simple value whose value does not change asynchronously, you must implement the get_value/1 and put_value/2 callbacks. These callbacks each take a set of opts (specified in the initial configuration passed to HAP.start_link/1) to allow your implementation to discriminate between various values within the same HAP.ValueStore module.Supporting Asynchronous NotificationsTo support notifying HomeKit of changes to an accessory's characteristics (such as a user pressing a button or a flood sensor detecting water), implementations of HAP.ValueStore may choose to implement the optional set_change_token/2 callback. This callback will provide your implementation with a change token to use when notifying HAP of changes to the corresponding value. To notify HAP of changes to a value, pass this change token to the HAP.value_changed/1 function. HAP will then query your value store for the new value of the corresponding characteristic and notify any HomeKit controllers of the change.There are a number of things to be aware of when using Asynchronous Notifications:Your value store must be prepared to answer calls to get_value/1 with the updated value before calling HAP.value_changed/1.Do not call HAP.value_changed/1 to notify HAP of changes which come from HAP itself (ie: do not call it in the course of implementing put_value/2). Use it only for notifying HAP of changes which are truly asynchronous.If you have not yet received a set_change_token/2 call, then you should not call HAP.value_changed/1; HAP will only provide you with a change token for characteristics which a HomeKit controller has requested notifications on. Specifically, do not retain change tokens between runs; they should maintain the same lifetime as the underlying HAP process.The call to HAP.value_changed/1 is guaranteed to return quickly. It does no work beyond casting a message to HAP to set the notification process in motion.","ref":"HAP.ValueStore.html","title":"HAP.ValueStore","type":"behaviour"},{"doc":"Return the value of a value hosted by this value store. The passed list of opts is as specified in the hosting HAP.Configuration and can be used to distinguish a particular value within a larger value store (perhaps by GPIO pin or similar)Returns the value stored by this value store","ref":"HAP.ValueStore.html#c:get_value/1","title":"HAP.ValueStore.get_value/1","type":"callback"},{"doc":"Sets the value of a value hosted by this value store. The passed list of opts is as specified in the hosting HAP.Configuration and can be used to distinguish a particular value within a larger value store (perhaps by GPIO pin or similar)Returns :ok or {:error, reason}","ref":"HAP.ValueStore.html#c:put_value/2","title":"HAP.ValueStore.put_value/2","type":"callback"},{"doc":"Informs the value store of the change token to use when notifying HAP of asynchronous changes to the value in this store. This token should be provided to HAP.value_changed/1 as the sole argument; HAP will make a subsequent call to get_value/1 to obtain the changed valueReturns :ok or {:error, reason}","ref":"HAP.ValueStore.html#c:set_change_token/2","title":"HAP.ValueStore.set_change_token/2","type":"callback"},{"doc":"","ref":"HAP.ValueStore.html#t:change_token/0","title":"HAP.ValueStore.change_token/0","type":"opaque"},{"doc":"","ref":"HAP.ValueStore.html#t:opts/0","title":"HAP.ValueStore.opts/0","type":"type"},{"doc":"","ref":"HAP.ValueStore.html#t:t/0","title":"HAP.ValueStore.t/0","type":"type"},{"doc":"Represents a single service, containing a number of characteristics","ref":"HAP.Service.html","title":"HAP.Service","type":"module"},{"doc":"Represents a service of a given type, containing a number of characteristics","ref":"HAP.Service.html#t:t/0","title":"HAP.Service.t/0","type":"type"},{"doc":"The type of a service as defined in Section 6.6.1 of Apple's HomeKit Accessory Protocol Specification.","ref":"HAP.Service.html#t:type/0","title":"HAP.Service.type/0","type":"type"},{"doc":"A protocol which allows for arbitrary service definitions to compile themselves into HAP.Service structs for use within HAP. This protocol allows HAP to expose pre-defined services such as HAP.Services.Lightbulb with fields reflecting the domain of the service, while allowing HAP to work internally with a service tree close to taht defined in the HomeKit specification","ref":"HAP.ServiceSource.html","title":"HAP.ServiceSource","type":"protocol"},{"doc":"Compile the given value into a HAP.Service struct","ref":"HAP.ServiceSource.html#compile/1","title":"HAP.ServiceSource.compile/1","type":"function"},{"doc":"","ref":"HAP.ServiceSource.html#t:t/0","title":"HAP.ServiceSource.t/0","type":"type"},{"doc":"Struct representing an instance of the public.hap.service.accessory-information service","ref":"HAP.Services.AccessoryInformation.html","title":"HAP.Services.AccessoryInformation","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.sensor.contact service","ref":"HAP.Services.ContactSensor.html","title":"HAP.Services.ContactSensor","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.heater-cooler service","ref":"HAP.Services.HeaterCooler.html","title":"HAP.Services.HeaterCooler","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.sensor.leak service","ref":"HAP.Services.LeakSensor.html","title":"HAP.Services.LeakSensor","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.lightbulb service","ref":"HAP.Services.LightBulb.html","title":"HAP.Services.LightBulb","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.sensor.light service","ref":"HAP.Services.LightSensor.html","title":"HAP.Services.LightSensor","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.sensor.motion service","ref":"HAP.Services.MotionSensor.html","title":"HAP.Services.MotionSensor","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.sensor.occupancy service","ref":"HAP.Services.OccupancySensor.html","title":"HAP.Services.OccupancySensor","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.outlet service","ref":"HAP.Services.Outlet.html","title":"HAP.Services.Outlet","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.protocol.information.service service","ref":"HAP.Services.ProtocolInformation.html","title":"HAP.Services.ProtocolInformation","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.switch service","ref":"HAP.Services.Switch.html","title":"HAP.Services.Switch","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.sensor.temperature service","ref":"HAP.Services.TemperatureSensor.html","title":"HAP.Services.TemperatureSensor","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.window service","ref":"HAP.Services.Window.html","title":"HAP.Services.Window","type":"module"},{"doc":"Struct representing an instance of the public.hap.service.window-covering service","ref":"HAP.Services.WindowCovering.html","title":"HAP.Services.WindowCovering","type":"module"},{"doc":"Functions to aid in the manipulation of characteristics tuples","ref":"HAP.Characteristic.html","title":"HAP.Characteristic","type":"module"},{"doc":"Represents a single characteristic consisting of a static definition and a value source","ref":"HAP.Characteristic.html#t:t/0","title":"HAP.Characteristic.t/0","type":"type"},{"doc":"The resolved value of a characteristic","ref":"HAP.Characteristic.html#t:value/0","title":"HAP.Characteristic.value/0","type":"type"},{"doc":"Represents a source for a characteristic value. May be either a static literal or a {mod, opts} tuple which is consulted when reading / writing a characteristic","ref":"HAP.Characteristic.html#t:value_source/0","title":"HAP.Characteristic.value_source/0","type":"type"},{"doc":"A behaviour which encapsulates the functinos required to define a characteristic. At runtime, characteristics are modeled via the HAP.Characteristic struct which contains the runtime values for the characteristic itself, as well as metadata about the characteristic. A HAP.CharacteristicDefinition is used to provide the template values for these fields. HAP contains definitions for many common HomeKit characteristics already, and users may define other characteristics by providing an implemenation of this behaviour as the first value in the characteristic definition tuple in a service.","ref":"HAP.CharacteristicDefinition.html","title":"HAP.CharacteristicDefinition","type":"behaviour"},{"doc":"The format of this characteristic's data","ref":"HAP.CharacteristicDefinition.html#c:format/0","title":"HAP.CharacteristicDefinition.format/0","type":"callback"},{"doc":"The maximum value allowed for this characteristic's value","ref":"HAP.CharacteristicDefinition.html#c:max_value/0","title":"HAP.CharacteristicDefinition.max_value/0","type":"callback"},{"doc":"The minimum value allowed for this characteristic's value","ref":"HAP.CharacteristicDefinition.html#c:min_value/0","title":"HAP.CharacteristicDefinition.min_value/0","type":"callback"},{"doc":"The permissions to allow for this characteristic","ref":"HAP.CharacteristicDefinition.html#c:perms/0","title":"HAP.CharacteristicDefinition.perms/0","type":"callback"},{"doc":"The step size by which this characteristic's value may change","ref":"HAP.CharacteristicDefinition.html#c:step_value/0","title":"HAP.CharacteristicDefinition.step_value/0","type":"callback"},{"doc":"The HomeKit type code for this characteristic","ref":"HAP.CharacteristicDefinition.html#c:type/0","title":"HAP.CharacteristicDefinition.type/0","type":"callback"},{"doc":"The units of this Characteristic's value","ref":"HAP.CharacteristicDefinition.html#c:units/0","title":"HAP.CharacteristicDefinition.units/0","type":"callback"},{"doc":"The format of a characteristic as defined in Table 6.5 of Apple's HomeKit Accessory Protocol Specification. One of bool, uint8, uint16, uint32, uint64, int, float, string, tlv8, or data","ref":"HAP.CharacteristicDefinition.html#t:format/0","title":"HAP.CharacteristicDefinition.format/0","type":"type"},{"doc":"A permission of a characteristic as defined in Table 6.4 of Apple's HomeKit Accessory Protocol Specification. One of pr, pw, ev, aa, tw, hd, or wr","ref":"HAP.CharacteristicDefinition.html#t:perm/0","title":"HAP.CharacteristicDefinition.perm/0","type":"type"},{"doc":"The type of a characteristic as defined in Section 6.6.1 of Apple's HomeKit Accessory Protocol Specification.","ref":"HAP.CharacteristicDefinition.html#t:type/0","title":"HAP.CharacteristicDefinition.type/0","type":"type"},{"doc":"The unit of measure of a characrteristic's value","ref":"HAP.CharacteristicDefinition.html#t:unit/0","title":"HAP.CharacteristicDefinition.unit/0","type":"type"},{"doc":"Definition of the public.hap.characteristic.active characteristic","ref":"HAP.Characteristics.Active.html","title":"HAP.Characteristics.Active","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.Active.html#format/0","title":"HAP.Characteristics.Active.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.Active.html#max_value/0","title":"HAP.Characteristics.Active.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.Active.html#min_value/0","title":"HAP.Characteristics.Active.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.Active.html#perms/0","title":"HAP.Characteristics.Active.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.Active.html#step_value/0","title":"HAP.Characteristics.Active.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.Active.html#type/0","title":"HAP.Characteristics.Active.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.brightness characteristic","ref":"HAP.Characteristics.Brightness.html","title":"HAP.Characteristics.Brightness","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.Brightness.html#format/0","title":"HAP.Characteristics.Brightness.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.Brightness.html#max_value/0","title":"HAP.Characteristics.Brightness.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.Brightness.html#min_value/0","title":"HAP.Characteristics.Brightness.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.Brightness.html#perms/0","title":"HAP.Characteristics.Brightness.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.Brightness.html#step_value/0","title":"HAP.Characteristics.Brightness.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.Brightness.html#type/0","title":"HAP.Characteristics.Brightness.type/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.Brightness.html#unit/0","title":"HAP.Characteristics.Brightness.unit/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.color-temperature characteristicThis characteristic describes color temperature which is represented in reciprocal megaKelvin (MK-1) or mirek scale. (M = 1,000,000 / K where M is the desired mirek value and K is temperature in Kelvin)","ref":"HAP.Characteristics.ColorTemperature.html","title":"HAP.Characteristics.ColorTemperature","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.ColorTemperature.html#format/0","title":"HAP.Characteristics.ColorTemperature.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.ColorTemperature.html#max_value/0","title":"HAP.Characteristics.ColorTemperature.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.ColorTemperature.html#min_value/0","title":"HAP.Characteristics.ColorTemperature.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.ColorTemperature.html#perms/0","title":"HAP.Characteristics.ColorTemperature.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.ColorTemperature.html#step_value/0","title":"HAP.Characteristics.ColorTemperature.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.ColorTemperature.html#type/0","title":"HAP.Characteristics.ColorTemperature.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.contact-state characteristicA value of 0 indicates that the contact is detected. A value of 1 indicates that the contact is not detected.","ref":"HAP.Characteristics.ContactSensorState.html","title":"HAP.Characteristics.ContactSensorState","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.ContactSensorState.html#format/0","title":"HAP.Characteristics.ContactSensorState.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.ContactSensorState.html#max_value/0","title":"HAP.Characteristics.ContactSensorState.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.ContactSensorState.html#min_value/0","title":"HAP.Characteristics.ContactSensorState.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.ContactSensorState.html#perms/0","title":"HAP.Characteristics.ContactSensorState.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.ContactSensorState.html#step_value/0","title":"HAP.Characteristics.ContactSensorState.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.ContactSensorState.html#type/0","title":"HAP.Characteristics.ContactSensorState.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.temperature.cooling-threshold characteristic","ref":"HAP.Characteristics.CoolingThresholdTemperature.html","title":"HAP.Characteristics.CoolingThresholdTemperature","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#format/0","title":"HAP.Characteristics.CoolingThresholdTemperature.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#max_value/0","title":"HAP.Characteristics.CoolingThresholdTemperature.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#min_value/0","title":"HAP.Characteristics.CoolingThresholdTemperature.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#perms/0","title":"HAP.Characteristics.CoolingThresholdTemperature.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#step_value/0","title":"HAP.Characteristics.CoolingThresholdTemperature.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#type/0","title":"HAP.Characteristics.CoolingThresholdTemperature.type/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.units/0.","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#units/0","title":"HAP.Characteristics.CoolingThresholdTemperature.units/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.light-level.current characteristic","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html","title":"HAP.Characteristics.CurrentAmbientLightLevel","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#format/0","title":"HAP.Characteristics.CurrentAmbientLightLevel.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#max_value/0","title":"HAP.Characteristics.CurrentAmbientLightLevel.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#min_value/0","title":"HAP.Characteristics.CurrentAmbientLightLevel.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#perms/0","title":"HAP.Characteristics.CurrentAmbientLightLevel.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#type/0","title":"HAP.Characteristics.CurrentAmbientLightLevel.type/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.units/0.","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#units/0","title":"HAP.Characteristics.CurrentAmbientLightLevel.units/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.heater-cooler.state.current characteristicValid values:0 Inactive 1 Idle 2 Heating 3 Cooling","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html","title":"HAP.Characteristics.CurrentHeaterCoolerState","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#format/0","title":"HAP.Characteristics.CurrentHeaterCoolerState.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#max_value/0","title":"HAP.Characteristics.CurrentHeaterCoolerState.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#min_value/0","title":"HAP.Characteristics.CurrentHeaterCoolerState.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#perms/0","title":"HAP.Characteristics.CurrentHeaterCoolerState.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#step_value/0","title":"HAP.Characteristics.CurrentHeaterCoolerState.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#type/0","title":"HAP.Characteristics.CurrentHeaterCoolerState.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.horizontal-tilt.current characteristic","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html","title":"HAP.Characteristics.CurrentHorizontalTiltAngle","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#format/0","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#max_value/0","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#min_value/0","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#perms/0","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#step_value/0","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#type/0","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.type/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.units/0.","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#units/0","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.units/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.position.current characteristic","ref":"HAP.Characteristics.CurrentPosition.html","title":"HAP.Characteristics.CurrentPosition","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.CurrentPosition.html#format/0","title":"HAP.Characteristics.CurrentPosition.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.CurrentPosition.html#max_value/0","title":"HAP.Characteristics.CurrentPosition.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.CurrentPosition.html#min_value/0","title":"HAP.Characteristics.CurrentPosition.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.CurrentPosition.html#perms/0","title":"HAP.Characteristics.CurrentPosition.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.CurrentPosition.html#step_value/0","title":"HAP.Characteristics.CurrentPosition.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.CurrentPosition.html#type/0","title":"HAP.Characteristics.CurrentPosition.type/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.CurrentPosition.html#unit/0","title":"HAP.Characteristics.CurrentPosition.unit/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.temperature.current characteristic","ref":"HAP.Characteristics.CurrentTemperature.html","title":"HAP.Characteristics.CurrentTemperature","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.CurrentTemperature.html#format/0","title":"HAP.Characteristics.CurrentTemperature.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.CurrentTemperature.html#max_value/0","title":"HAP.Characteristics.CurrentTemperature.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.CurrentTemperature.html#min_value/0","title":"HAP.Characteristics.CurrentTemperature.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.CurrentTemperature.html#perms/0","title":"HAP.Characteristics.CurrentTemperature.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.CurrentTemperature.html#step_value/0","title":"HAP.Characteristics.CurrentTemperature.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.CurrentTemperature.html#type/0","title":"HAP.Characteristics.CurrentTemperature.type/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.CurrentTemperature.html#unit/0","title":"HAP.Characteristics.CurrentTemperature.unit/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.vertical-tilt.current characteristic","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html","title":"HAP.Characteristics.CurrentVerticalTiltAngle","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#format/0","title":"HAP.Characteristics.CurrentVerticalTiltAngle.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#max_value/0","title":"HAP.Characteristics.CurrentVerticalTiltAngle.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#min_value/0","title":"HAP.Characteristics.CurrentVerticalTiltAngle.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#perms/0","title":"HAP.Characteristics.CurrentVerticalTiltAngle.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#step_value/0","title":"HAP.Characteristics.CurrentVerticalTiltAngle.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#type/0","title":"HAP.Characteristics.CurrentVerticalTiltAngle.type/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.units/0.","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#units/0","title":"HAP.Characteristics.CurrentVerticalTiltAngle.units/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.firmware.revision characteristic","ref":"HAP.Characteristics.FirmwareRevision.html","title":"HAP.Characteristics.FirmwareRevision","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.FirmwareRevision.html#format/0","title":"HAP.Characteristics.FirmwareRevision.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.FirmwareRevision.html#perms/0","title":"HAP.Characteristics.FirmwareRevision.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.FirmwareRevision.html#type/0","title":"HAP.Characteristics.FirmwareRevision.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.temperature.heating-threshold characteristic","ref":"HAP.Characteristics.HeatingThresholdTemperature.html","title":"HAP.Characteristics.HeatingThresholdTemperature","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#format/0","title":"HAP.Characteristics.HeatingThresholdTemperature.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#max_value/0","title":"HAP.Characteristics.HeatingThresholdTemperature.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#min_value/0","title":"HAP.Characteristics.HeatingThresholdTemperature.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#perms/0","title":"HAP.Characteristics.HeatingThresholdTemperature.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#step_value/0","title":"HAP.Characteristics.HeatingThresholdTemperature.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#type/0","title":"HAP.Characteristics.HeatingThresholdTemperature.type/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.units/0.","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#units/0","title":"HAP.Characteristics.HeatingThresholdTemperature.units/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.position.hold characteristic","ref":"HAP.Characteristics.HoldPosition.html","title":"HAP.Characteristics.HoldPosition","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.HoldPosition.html#format/0","title":"HAP.Characteristics.HoldPosition.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.HoldPosition.html#perms/0","title":"HAP.Characteristics.HoldPosition.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.HoldPosition.html#type/0","title":"HAP.Characteristics.HoldPosition.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.hue characteristic","ref":"HAP.Characteristics.Hue.html","title":"HAP.Characteristics.Hue","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.Hue.html#format/0","title":"HAP.Characteristics.Hue.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.Hue.html#max_value/0","title":"HAP.Characteristics.Hue.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.Hue.html#min_value/0","title":"HAP.Characteristics.Hue.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.Hue.html#perms/0","title":"HAP.Characteristics.Hue.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.Hue.html#step_value/0","title":"HAP.Characteristics.Hue.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.Hue.html#type/0","title":"HAP.Characteristics.Hue.type/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.Hue.html#unit/0","title":"HAP.Characteristics.Hue.unit/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.identify characteristic","ref":"HAP.Characteristics.Identify.html","title":"HAP.Characteristics.Identify","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.Identify.html#format/0","title":"HAP.Characteristics.Identify.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.Identify.html#perms/0","title":"HAP.Characteristics.Identify.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.Identify.html#type/0","title":"HAP.Characteristics.Identify.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.leak-detected characteristicValid values: 0: Leak is not detected 1: Leak is detected","ref":"HAP.Characteristics.LeakDetected.html","title":"HAP.Characteristics.LeakDetected","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.LeakDetected.html#format/0","title":"HAP.Characteristics.LeakDetected.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.LeakDetected.html#max_value/0","title":"HAP.Characteristics.LeakDetected.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.LeakDetected.html#min_value/0","title":"HAP.Characteristics.LeakDetected.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.LeakDetected.html#perms/0","title":"HAP.Characteristics.LeakDetected.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.LeakDetected.html#step_value/0","title":"HAP.Characteristics.LeakDetected.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.LeakDetected.html#type/0","title":"HAP.Characteristics.LeakDetected.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.lock-physical-controls characteristicValid values: 0: Control lock disabled 1: Control lock enabled","ref":"HAP.Characteristics.LockPhysicalControls.html","title":"HAP.Characteristics.LockPhysicalControls","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.LockPhysicalControls.html#format/0","title":"HAP.Characteristics.LockPhysicalControls.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.LockPhysicalControls.html#max_value/0","title":"HAP.Characteristics.LockPhysicalControls.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.LockPhysicalControls.html#min_value/0","title":"HAP.Characteristics.LockPhysicalControls.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.LockPhysicalControls.html#perms/0","title":"HAP.Characteristics.LockPhysicalControls.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.LockPhysicalControls.html#step_value/0","title":"HAP.Characteristics.LockPhysicalControls.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.LockPhysicalControls.html#type/0","title":"HAP.Characteristics.LockPhysicalControls.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.manufacturer characteristic","ref":"HAP.Characteristics.Manufacturer.html","title":"HAP.Characteristics.Manufacturer","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.Manufacturer.html#format/0","title":"HAP.Characteristics.Manufacturer.format/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.Manufacturer.html#max_length/0","title":"HAP.Characteristics.Manufacturer.max_length/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.Manufacturer.html#perms/0","title":"HAP.Characteristics.Manufacturer.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.Manufacturer.html#type/0","title":"HAP.Characteristics.Manufacturer.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.model characteristic","ref":"HAP.Characteristics.Model.html","title":"HAP.Characteristics.Model","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.Model.html#format/0","title":"HAP.Characteristics.Model.format/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.Model.html#max_length/0","title":"HAP.Characteristics.Model.max_length/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.Model.html#perms/0","title":"HAP.Characteristics.Model.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.Model.html#type/0","title":"HAP.Characteristics.Model.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.motion-detected characteristic","ref":"HAP.Characteristics.MotionDetected.html","title":"HAP.Characteristics.MotionDetected","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.MotionDetected.html#format/0","title":"HAP.Characteristics.MotionDetected.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.MotionDetected.html#perms/0","title":"HAP.Characteristics.MotionDetected.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.MotionDetected.html#type/0","title":"HAP.Characteristics.MotionDetected.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.name characteristic","ref":"HAP.Characteristics.Name.html","title":"HAP.Characteristics.Name","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.Name.html#format/0","title":"HAP.Characteristics.Name.format/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.Name.html#max_length/0","title":"HAP.Characteristics.Name.max_length/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.Name.html#perms/0","title":"HAP.Characteristics.Name.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.Name.html#type/0","title":"HAP.Characteristics.Name.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.obstruction-detected characteristic","ref":"HAP.Characteristics.ObstructionDetected.html","title":"HAP.Characteristics.ObstructionDetected","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.ObstructionDetected.html#format/0","title":"HAP.Characteristics.ObstructionDetected.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.ObstructionDetected.html#perms/0","title":"HAP.Characteristics.ObstructionDetected.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.ObstructionDetected.html#type/0","title":"HAP.Characteristics.ObstructionDetected.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.occupancy-detected characteristicValid values: 0: Occupancy is not detected 1: Occupancy is detected","ref":"HAP.Characteristics.OccupancyDetected.html","title":"HAP.Characteristics.OccupancyDetected","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.OccupancyDetected.html#format/0","title":"HAP.Characteristics.OccupancyDetected.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.OccupancyDetected.html#max_value/0","title":"HAP.Characteristics.OccupancyDetected.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.OccupancyDetected.html#min_value/0","title":"HAP.Characteristics.OccupancyDetected.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.OccupancyDetected.html#perms/0","title":"HAP.Characteristics.OccupancyDetected.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.OccupancyDetected.html#step_value/0","title":"HAP.Characteristics.OccupancyDetected.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.OccupancyDetected.html#type/0","title":"HAP.Characteristics.OccupancyDetected.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.on characteristic","ref":"HAP.Characteristics.On.html","title":"HAP.Characteristics.On","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.On.html#format/0","title":"HAP.Characteristics.On.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.On.html#perms/0","title":"HAP.Characteristics.On.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.On.html#type/0","title":"HAP.Characteristics.On.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.outlet-in-use characteristic","ref":"HAP.Characteristics.OutletInUse.html","title":"HAP.Characteristics.OutletInUse","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.OutletInUse.html#format/0","title":"HAP.Characteristics.OutletInUse.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.OutletInUse.html#perms/0","title":"HAP.Characteristics.OutletInUse.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.OutletInUse.html#type/0","title":"HAP.Characteristics.OutletInUse.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.position.state characteristicValid values: 0: Going to the minimum value specified in metadata 1: Going to the maximum value specified in metadata 2: Stopped","ref":"HAP.Characteristics.PositionState.html","title":"HAP.Characteristics.PositionState","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.PositionState.html#format/0","title":"HAP.Characteristics.PositionState.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.PositionState.html#max_value/0","title":"HAP.Characteristics.PositionState.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.PositionState.html#min_value/0","title":"HAP.Characteristics.PositionState.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.PositionState.html#perms/0","title":"HAP.Characteristics.PositionState.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.PositionState.html#step_value/0","title":"HAP.Characteristics.PositionState.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.PositionState.html#type/0","title":"HAP.Characteristics.PositionState.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.rotation.speed characteristic","ref":"HAP.Characteristics.RotationSpeed.html","title":"HAP.Characteristics.RotationSpeed","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.RotationSpeed.html#format/0","title":"HAP.Characteristics.RotationSpeed.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.RotationSpeed.html#max_value/0","title":"HAP.Characteristics.RotationSpeed.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.RotationSpeed.html#min_value/0","title":"HAP.Characteristics.RotationSpeed.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.RotationSpeed.html#perms/0","title":"HAP.Characteristics.RotationSpeed.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.RotationSpeed.html#step_value/0","title":"HAP.Characteristics.RotationSpeed.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.RotationSpeed.html#type/0","title":"HAP.Characteristics.RotationSpeed.type/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.RotationSpeed.html#unit/0","title":"HAP.Characteristics.RotationSpeed.unit/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.saturation characteristic","ref":"HAP.Characteristics.Saturation.html","title":"HAP.Characteristics.Saturation","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.Saturation.html#format/0","title":"HAP.Characteristics.Saturation.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.Saturation.html#max_value/0","title":"HAP.Characteristics.Saturation.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.Saturation.html#min_value/0","title":"HAP.Characteristics.Saturation.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.Saturation.html#perms/0","title":"HAP.Characteristics.Saturation.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.Saturation.html#step_value/0","title":"HAP.Characteristics.Saturation.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.Saturation.html#type/0","title":"HAP.Characteristics.Saturation.type/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.Saturation.html#unit/0","title":"HAP.Characteristics.Saturation.unit/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.serial-number characteristic","ref":"HAP.Characteristics.SerialNumber.html","title":"HAP.Characteristics.SerialNumber","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.SerialNumber.html#format/0","title":"HAP.Characteristics.SerialNumber.format/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.SerialNumber.html#max_length/0","title":"HAP.Characteristics.SerialNumber.max_length/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.SerialNumber.html#perms/0","title":"HAP.Characteristics.SerialNumber.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.SerialNumber.html#type/0","title":"HAP.Characteristics.SerialNumber.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.status-active characteristic","ref":"HAP.Characteristics.StatusActive.html","title":"HAP.Characteristics.StatusActive","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.StatusActive.html#format/0","title":"HAP.Characteristics.StatusActive.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.StatusActive.html#perms/0","title":"HAP.Characteristics.StatusActive.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.StatusActive.html#type/0","title":"HAP.Characteristics.StatusActive.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.status-fault characteristicA non-zero value indicates that the accessory has experienced a fault that may be interfering with its intended functionality. A value of 0 indicates that there is no fault.","ref":"HAP.Characteristics.StatusFault.html","title":"HAP.Characteristics.StatusFault","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.StatusFault.html#format/0","title":"HAP.Characteristics.StatusFault.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.StatusFault.html#max_value/0","title":"HAP.Characteristics.StatusFault.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.StatusFault.html#min_value/0","title":"HAP.Characteristics.StatusFault.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.StatusFault.html#perms/0","title":"HAP.Characteristics.StatusFault.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.StatusFault.html#step_value/0","title":"HAP.Characteristics.StatusFault.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.StatusFault.html#type/0","title":"HAP.Characteristics.StatusFault.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.status-lo-batt characteristicA status of 1 indicates that the battery level of the accessory is low. Value should return to 0 when the battery charges to a level thats above the low threshold.","ref":"HAP.Characteristics.StatusLowBattery.html","title":"HAP.Characteristics.StatusLowBattery","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.StatusLowBattery.html#format/0","title":"HAP.Characteristics.StatusLowBattery.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.StatusLowBattery.html#max_value/0","title":"HAP.Characteristics.StatusLowBattery.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.StatusLowBattery.html#min_value/0","title":"HAP.Characteristics.StatusLowBattery.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.StatusLowBattery.html#perms/0","title":"HAP.Characteristics.StatusLowBattery.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.StatusLowBattery.html#step_value/0","title":"HAP.Characteristics.StatusLowBattery.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.StatusLowBattery.html#type/0","title":"HAP.Characteristics.StatusLowBattery.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.status-tampered characteristicThis characteristic describes an accessory which has been tampered with. A status of 1 indicates that the accessory has been tampered with. Value should return to 0 when the accessory has been reset to a non-tampered state.","ref":"HAP.Characteristics.StatusTampered.html","title":"HAP.Characteristics.StatusTampered","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.StatusTampered.html#format/0","title":"HAP.Characteristics.StatusTampered.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.StatusTampered.html#max_value/0","title":"HAP.Characteristics.StatusTampered.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.StatusTampered.html#min_value/0","title":"HAP.Characteristics.StatusTampered.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.StatusTampered.html#perms/0","title":"HAP.Characteristics.StatusTampered.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.StatusTampered.html#step_value/0","title":"HAP.Characteristics.StatusTampered.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.StatusTampered.html#type/0","title":"HAP.Characteristics.StatusTampered.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.swing-mode characteristicValid values:0: Swing disabled 1: Swing enabled","ref":"HAP.Characteristics.SwingMode.html","title":"HAP.Characteristics.SwingMode","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.SwingMode.html#format/0","title":"HAP.Characteristics.SwingMode.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.SwingMode.html#max_value/0","title":"HAP.Characteristics.SwingMode.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.SwingMode.html#min_value/0","title":"HAP.Characteristics.SwingMode.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.SwingMode.html#perms/0","title":"HAP.Characteristics.SwingMode.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.SwingMode.html#step_value/0","title":"HAP.Characteristics.SwingMode.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.SwingMode.html#type/0","title":"HAP.Characteristics.SwingMode.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.heater-cooler.target characteristicValid values: 0 Off 1 Heat (if current temperature is below the target temperature then turn on heating) 2 Cooling (if current temperature is above the target temperature then turn on cooling) 3 Auto (turn on heating or cooling to maintain temperature within the target temperatures)","ref":"HAP.Characteristics.TargetHeaterCoolerState.html","title":"HAP.Characteristics.TargetHeaterCoolerState","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#format/0","title":"HAP.Characteristics.TargetHeaterCoolerState.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#max_value/0","title":"HAP.Characteristics.TargetHeaterCoolerState.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#min_value/0","title":"HAP.Characteristics.TargetHeaterCoolerState.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#perms/0","title":"HAP.Characteristics.TargetHeaterCoolerState.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#step_value/0","title":"HAP.Characteristics.TargetHeaterCoolerState.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#type/0","title":"HAP.Characteristics.TargetHeaterCoolerState.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.horizontal-tilt.target characteristic","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html","title":"HAP.Characteristics.TargetHorizontalTiltAngle","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#format/0","title":"HAP.Characteristics.TargetHorizontalTiltAngle.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#max_value/0","title":"HAP.Characteristics.TargetHorizontalTiltAngle.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#min_value/0","title":"HAP.Characteristics.TargetHorizontalTiltAngle.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#perms/0","title":"HAP.Characteristics.TargetHorizontalTiltAngle.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#step_value/0","title":"HAP.Characteristics.TargetHorizontalTiltAngle.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#type/0","title":"HAP.Characteristics.TargetHorizontalTiltAngle.type/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.units/0.","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#units/0","title":"HAP.Characteristics.TargetHorizontalTiltAngle.units/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.position.target characteristic","ref":"HAP.Characteristics.TargetPosition.html","title":"HAP.Characteristics.TargetPosition","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.TargetPosition.html#format/0","title":"HAP.Characteristics.TargetPosition.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.TargetPosition.html#max_value/0","title":"HAP.Characteristics.TargetPosition.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.TargetPosition.html#min_value/0","title":"HAP.Characteristics.TargetPosition.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.TargetPosition.html#perms/0","title":"HAP.Characteristics.TargetPosition.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.TargetPosition.html#step_value/0","title":"HAP.Characteristics.TargetPosition.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.TargetPosition.html#type/0","title":"HAP.Characteristics.TargetPosition.type/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.TargetPosition.html#unit/0","title":"HAP.Characteristics.TargetPosition.unit/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.vertical-tilt.target characteristic","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html","title":"HAP.Characteristics.TargetVerticalTiltAngle","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#format/0","title":"HAP.Characteristics.TargetVerticalTiltAngle.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#max_value/0","title":"HAP.Characteristics.TargetVerticalTiltAngle.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#min_value/0","title":"HAP.Characteristics.TargetVerticalTiltAngle.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#perms/0","title":"HAP.Characteristics.TargetVerticalTiltAngle.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#step_value/0","title":"HAP.Characteristics.TargetVerticalTiltAngle.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#type/0","title":"HAP.Characteristics.TargetVerticalTiltAngle.type/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.units/0.","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#units/0","title":"HAP.Characteristics.TargetVerticalTiltAngle.units/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.temperature.units characteristicValid values:0: Celsius 1: Fahrenheit","ref":"HAP.Characteristics.TemperatureDisplayUnits.html","title":"HAP.Characteristics.TemperatureDisplayUnits","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#format/0","title":"HAP.Characteristics.TemperatureDisplayUnits.format/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.max_value/0.","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#max_value/0","title":"HAP.Characteristics.TemperatureDisplayUnits.max_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.min_value/0.","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#min_value/0","title":"HAP.Characteristics.TemperatureDisplayUnits.min_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#perms/0","title":"HAP.Characteristics.TemperatureDisplayUnits.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.step_value/0.","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#step_value/0","title":"HAP.Characteristics.TemperatureDisplayUnits.step_value/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#type/0","title":"HAP.Characteristics.TemperatureDisplayUnits.type/0","type":"function"},{"doc":"Definition of the public.hap.characteristic.version characteristic","ref":"HAP.Characteristics.Version.html","title":"HAP.Characteristics.Version","type":"module"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.format/0.","ref":"HAP.Characteristics.Version.html#format/0","title":"HAP.Characteristics.Version.format/0","type":"function"},{"doc":"","ref":"HAP.Characteristics.Version.html#max_length/0","title":"HAP.Characteristics.Version.max_length/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.perms/0.","ref":"HAP.Characteristics.Version.html#perms/0","title":"HAP.Characteristics.Version.perms/0","type":"function"},{"doc":"Callback implementation for HAP.CharacteristicDefinition.type/0.","ref":"HAP.Characteristics.Version.html#type/0","title":"HAP.Characteristics.Version.type/0","type":"function"}]